@@ -2,23 +2,19 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import print_function
 
-import json
-
-from compas.base import Base
+from compas.data import Data
 from compas.files import URDFElement
 from compas.files import URDFParser
-from compas.geometry import Vector
-from compas.geometry import transform_vectors
 from compas.geometry import Rotation
 from compas.geometry import Transformation
 from compas.geometry import Translation
-
+from compas.geometry import Vector
+from compas.geometry import transform_vectors
 from compas.robots.model.geometry import Origin
-from compas.robots.model.geometry import _attr_to_data
 from compas.robots.model.geometry import _attr_from_data
+from compas.robots.model.geometry import _attr_to_data
 from compas.robots.model.geometry import _parse_floats
 
-
 __all__ = [
     'Joint',
     'ParentLink',
@@ -32,7 +28,7 @@ __all__ = [
 ]
 
 
-class ParentLink(Base):
+class ParentLink(Data):
     """Describes a parent relation between a joint its parent link."""
 
     def __init__(self, link):
@@ -59,21 +55,8 @@ class ParentLink(Base):
     def from_data(cls, data):
         return cls(data['link'])
 
-    def to_data(self):
-        return self.data
 
-    @classmethod
-    def from_json(cls, filepath):
-        with open(filepath, 'r') as fp:
-            data = json.load(fp)
-        return cls.from_data(data)
-
-    def to_json(self, filepath):
-        with open(filepath, 'w+') as f:
-            json.dump(self.data, f)
-
-
-class ChildLink(Base):
+class ChildLink(Data):
     """Describes a child relation between a joint and its child link."""
 
     def __init__(self, link):
@@ -100,21 +83,8 @@ class ChildLink(Base):
     def from_data(cls, data):
         return cls(data['link'])
 
-    def to_data(self):
-        return self.data
 
-    @classmethod
-    def from_json(cls, filepath):
-        with open(filepath, 'r') as fp:
-            data = json.load(fp)
-        return cls.from_data(data)
-
-    def to_json(self, filepath):
-        with open(filepath, 'w+') as f:
-            json.dump(self.data, f)
-
-
-class Calibration(Base):
+class Calibration(Data):
     """Reference positions of the joint, used to calibrate the absolute position."""
 
     def __init__(self, rising=0.0, falling=0.0, reference_position=0.0):
@@ -146,27 +116,8 @@ class Calibration(Base):
         self.falling = data['falling']
         self.reference_position = data['reference_position']
 
-    @classmethod
-    def from_data(cls, data):
-        calibration = cls()
-        calibration.data = data
-        return calibration
 
-    def to_data(self):
-        return self.data
-
-    @classmethod
-    def from_json(cls, filepath):
-        with open(filepath, 'r') as fp:
-            data = json.load(fp)
-        return cls.from_data(data)
-
-    def to_json(self, filepath):
-        with open(filepath, 'w+') as f:
-            json.dump(self.data, f)
-
-
-class Dynamics(Base):
+class Dynamics(Data):
     """Physical properties of the joint used for simulation of dynamics."""
 
     def __init__(self, damping=0.0, friction=0.0, **kwargs):
@@ -197,27 +148,8 @@ class Dynamics(Base):
         self.friction = data['friction']
         self.attr = _attr_from_data(data['attr'])
 
-    @classmethod
-    def from_data(cls, data):
-        dynamics = cls()
-        dynamics.data = data
-        return dynamics
 
-    def to_data(self):
-        return self.data
-
-    @classmethod
-    def from_json(cls, filepath):
-        with open(filepath, 'r') as fp:
-            data = json.load(fp)
-        return cls.from_data(data)
-
-    def to_json(self, filepath):
-        with open(filepath, 'w+') as f:
-            json.dump(self.data, f)
-
-
-class Limit(Base):
+class Limit(Data):
     """Joint limit properties.
 
     Attributes
@@ -265,25 +197,6 @@ class Limit(Base):
         self.lower = data['lower']
         self.upper = data['upper']
 
-    @classmethod
-    def from_data(cls, data):
-        limit = cls()
-        limit.data = data
-        return limit
-
-    def to_data(self):
-        return self.data
-
-    @classmethod
-    def from_json(cls, filepath):
-        with open(filepath, 'r') as fp:
-            data = json.load(fp)
-        return cls.from_data(data)
-
-    def to_json(self, filepath):
-        with open(filepath, 'w+') as f:
-            json.dump(self.data, f)
-
     def scale(self, factor):
         """Scale the upper and lower limits by a given factor.
 
@@ -300,7 +213,7 @@ class Limit(Base):
         self.upper *= factor
 
 
-class Mimic(Base):
+class Mimic(Data):
     """Description of joint mimic."""
 
     def __init__(self, joint, multiplier=1.0, offset=0.):
@@ -337,24 +250,11 @@ class Mimic(Base):
         mimic.data = data
         return mimic
 
-    def to_data(self):
-        return self.data
-
-    @classmethod
-    def from_json(cls, filepath):
-        with open(filepath, 'r') as fp:
-            data = json.load(fp)
-        return cls.from_data(data)
-
-    def to_json(self, filepath):
-        with open(filepath, 'w+') as f:
-            json.dump(self.data, f)
-
     def calculate_position(self, mimicked_joint_position):
         return self.multiplier * mimicked_joint_position + self.offset
 
 
-class SafetyController(Base):
+class SafetyController(Data):
     """Safety controller properties."""
 
     def __init__(self, k_velocity, k_position=0.0, soft_lower_limit=0.0, soft_upper_limit=0.0):
@@ -396,21 +296,8 @@ class SafetyController(Base):
         sc.data = data
         return sc
 
-    def to_data(self):
-        return self.data
 
-    @classmethod
-    def from_json(cls, filepath):
-        with open(filepath, 'r') as fp:
-            data = json.load(fp)
-        return cls.from_data(data)
-
-    def to_json(self, filepath):
-        with open(filepath, 'w+') as f:
-            json.dump(self.data, f)
-
-
-class Axis(Base):
+class Axis(Data):
     """Representation of an axis or vector.
 
     Attributes
@@ -456,25 +343,6 @@ class Axis(Base):
         self.z = data['z']
         self.attr = _attr_from_data(data['attr'])
 
-    @classmethod
-    def from_data(cls, data):
-        axis = cls()
-        axis.data = data
-        return axis
-
-    def to_data(self):
-        return self.data
-
-    @classmethod
-    def from_json(cls, filepath):
-        with open(filepath, 'r') as fp:
-            data = json.load(fp)
-        return cls.from_data(data)
-
-    def to_json(self, filepath):
-        with open(filepath, 'w+') as f:
-            json.dump(self.data, f)
-
     def copy(self):
         """Create a copy of the axis instance."""
         cls = type(self)
@@ -520,7 +388,7 @@ class Axis(Base):
         return "[%.3f, %.3f, %.3f]" % (self.x, self.y, self.z)
 
 
-class Joint(Base):
+class Joint(Data):
     """Representation of the kinematics and dynamics of a joint and its safety limits.
 
     Attributes
@@ -668,19 +536,6 @@ class Joint(Base):
         joint.data = data
         return joint
 
-    def to_data(self):
-        return self.data
-
-    @classmethod
-    def from_json(cls, filepath):
-        with open(filepath, 'r') as fp:
-            data = json.load(fp)
-        return cls.from_data(data)
-
-    def to_json(self, filepath):
-        with open(filepath, 'w+') as f:
-            json.dump(self.data, f)
-
     @property
     def current_transformation(self):
         """Current transformation of the joint."""
