@@ -15,11 +15,3 @@ class BaseArtist(object):
 
     def draw(self):
         raise NotImplementedError
-
-
-# ==============================================================================
-# Main
-# ==============================================================================
-
-if __name__ == '__main__':
-    pass
